@@ -31,9 +31,9 @@ function check_for_crashed_tables() {
   # Note that inside single quotes must be quoted with '\'' (to be outside of single quotes).
   set +e
   # The $MARIADB is intentionally used to expand into a command and arguments
-  # shellcheck disable=SC2086
+  # shellcheck disable=SC2086,SC2016
   echo '
-    SELECT CONCAT("select count(*) into @discard from '\''", TABLE_SCHEMA, "'\''.'\''", TABLE_NAME, "'\''")
+    SELECT CONCAT('\''select count(*) into @discard from `'\'', TABLE_SCHEMA, '\''`.`'\'', TABLE_NAME, '\''`'\'')
     FROM information_schema.TABLES WHERE TABLE_SCHEMA<>"INFORMATION_SCHEMA" AND TABLE_SCHEMA<>"PERFORMANCE_SCHEMA"
     AND (ENGINE="MyISAM" OR ENGINE="Aria")
     ' | \
